package me.lucko.luckperms.commands.user.subcommands;

import me.lucko.luckperms.LuckPermsPlugin;
import me.lucko.luckperms.commands.Sender;
import me.lucko.luckperms.commands.user.UserSubCommand;
import me.lucko.luckperms.constants.Message;
import me.lucko.luckperms.constants.Permission;
import me.lucko.luckperms.exceptions.ObjectLacksPermissionException;
import me.lucko.luckperms.users.User;

import java.util.List;

public class UserUnSetPermissionCommand extends UserSubCommand {
    public UserUnSetPermissionCommand() {
        super("unset", "Unsets a permission for a user",
                "/perms user <user> unset <node> [server]", Permission.USER_UNSETPERMISSION);
    }

    @Override
    protected void execute(LuckPermsPlugin plugin, Sender sender, User user, List<String> args) {
        String node = args.get(0);

        if (node.contains("/")) {
            sendUsage(sender);
            return;
        }

        if (node.matches("group\\..*")) {
            Message.USER_USE_REMOVEGROUP.send(sender);
            return;
        }

        try {
            if (args.size() == 2) {
                final String server = args.get(1).toLowerCase();
                user.unsetPermission(node, server);
                Message.UNSETPERMISSION_SERVER_SUCCESS.send(sender, node, user.getName(), server);
            } else {
                user.unsetPermission(node);
                Message.UNSETPERMISSION_SUCCESS.send(sender, node, user.getName());
            }

            saveUser(user, sender, plugin);
        } catch (ObjectLacksPermissionException e) {
            Message.DOES_NOT_HAVEPERMISSION.send(sender, user.getName());
        }
    }

    @Override
    public boolean isArgLengthInvalid(int argLength) {
        return argLength != 1 && argLength != 2;
    }
}
